<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:ecs="http://webservices.amazon.com/AWSECommerceService/2005-03-23"
  exclude-result-prefixes="ecs">

<xsl:output method="xml" version="1.0" encoding="UTF-8" indent="no" omit-xml-declaration="yes" />

<xsl:template match="/">
	<xsl:element name="div">
		<xsl:choose>
			<!-- ItemLookupResponse(ASIN検索) -->
			<xsl:when test="ecs:ItemLookupResponse">
				<xsl:apply-templates select="ecs:ItemLookupResponse/ecs:Items" />
			</xsl:when>
			<!-- ItemSearchResponse(キーワード検索) -->
			<xsl:when test="ecs:ItemSearchResponse">
				<xsl:apply-templates select="ecs:ItemSearchResponse/ecs:Items" />
			</xsl:when>
		</xsl:choose>
	</xsl:element>
</xsl:template>

<xsl:template match="ecs:Items">
	<xsl:if test="ecs:TotalResults">
		<xsl:element name="input">
			<xsl:attribute name="id">totalResults</xsl:attribute>
			<xsl:attribute name="type">hidden</xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="ecs:TotalResults" /></xsl:attribute>
		</xsl:element>
	</xsl:if>
	<xsl:if test="ecs:TotalPages">
		<xsl:element name="input">
			<xsl:attribute name="id">totalPages</xsl:attribute>
			<xsl:attribute name="type">hidden</xsl:attribute>
			<xsl:attribute name="value"><xsl:value-of select="ecs:TotalPages" /></xsl:attribute>
		</xsl:element>
	</xsl:if>
	<xsl:for-each select="ecs:Item">
		<xsl:sort select="ecs:ItemAttributes/ecs:Title" />
		<xsl:call-template name="Item" />
	</xsl:for-each>
	<xsl:apply-templates select="ecs:Request/ecs:Errors" />
</xsl:template>

<xsl:template name="Item">
	<table><tr>
		<td>
			<xsl:element name="a">
				<xsl:attribute name="href">http://www.amazon.co.jp/exec/obidos/ASIN/<xsl:value-of select="ecs:ASIN" />/<xsl:value-of select="../../ecs:OperationRequest/ecs:Arguments/ecs:Argument[@Name = 'AssociateTag']/@Value" />/ref=nosim/</xsl:attribute>
				<xsl:choose>
					<xsl:when test="ecs:SmallImage">
						<img src="{ecs:SmallImage/ecs:URL}" width="{ecs:SmallImage/ecs:Width}" height="{ecs:SmallImage/ecs:Height}" alt="{ecs:ItemAttributes/ecs:Title}" title="{ecs:ItemAttributes/ecs:Title}" border="0" />
					</xsl:when>
					<xsl:otherwise>
						<img src="/images/no_image.gif" width="60" height="60" alt="This has no image." title="This has no image." border="0" />
					</xsl:otherwise>
				</xsl:choose>
			</xsl:element>
		</td>
		<td>
			<ul>
				<li><xsl:element name="a">
					<xsl:attribute name="href">http://www.amazon.co.jp/exec/obidos/ASIN/<xsl:value-of select="ecs:ASIN" />/<xsl:value-of select="../../ecs:OperationRequest/ecs:Arguments/ecs:Argument[@Name = 'AssociateTag']/@Value" />/ref=nosim/</xsl:attribute>
					<xsl:value-of select="ecs:ItemAttributes/ecs:Title" />
				</xsl:element></li>
				<xsl:apply-templates select="ecs:ItemAttributes" />
				<xsl:apply-templates select="ecs:OfferSummary" />
				<li>ASIN：<xsl:value-of select="ecs:ASIN" /></li>
			</ul>
		</td>
	</tr></table>
</xsl:template>

<xsl:template match="ecs:ItemAttributes">
	<xsl:if test="ecs:Publisher">
		<li><xsl:value-of select="ecs:Publisher" /><xsl:if test="ecs:PublicationDate">(<xsl:value-of select="ecs:PublicationDate" />)</xsl:if></li>
	</xsl:if>
	<xsl:if test="ecs:Manufacturer">
		<li><xsl:value-of select="ecs:Manufacturer" /></li>
	</xsl:if>
	<xsl:for-each select="ecs:Creator">
		<li>(<xsl:value-of select="./@Role" />)<xsl:value-of select="." /></li>
	</xsl:for-each>
	<li>定価：<xsl:value-of select="ecs:ListPrice/ecs:FormattedPrice" /></li>
</xsl:template>

<xsl:template match="ecs:OfferSummary">
	<xsl:if test="ecs:LowestNewPrice">
		<li>新品価格：<xsl:value-of select="ecs:LowestNewPrice/ecs:FormattedPrice" /></li>
	</xsl:if>
	<xsl:if test="ecs:LowestUsedPrice">
		<li>中古価格：<xsl:value-of select="ecs:LowestUsedPrice/ecs:FormattedPrice" /></li>
	</xsl:if>
</xsl:template>

<xsl:template match="ecs:Errors">
	<xsl:for-each select="ecs:Error">
		<xsl:value-of select="ecs:Message" />
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
